@@ -14,7 +14,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: Device.h,v 1.17 2004/09/26 15:27:24 marka Exp $
+ * $Id: Device.h,v 1.18 2006/04/29 14:55:08 marka Exp $
  */
 #ifndef __Device_h
 #define __Device_h
@@ -88,6 +88,10 @@ public:
 	 */
 	virtual void read(DataBuffer& buf, bool verify=false) = 0;
 
+	/** Prepare the default value of the configuration registers.
+	 */
+	virtual void set_config_default(DataBuffer& buf) = 0;
+
 	/** Retrieves the name of the device.
 	 * \returns A string containing the name of the device.
 	 */
