@@ -14,7 +14,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: IO.cxx,v 1.14 2004/11/20 23:21:59 marka Exp $
+ * $Id: IO.cxx,v 1.15 2006/04/09 16:05:43 marka Exp $
  */
 using namespace std;
 
@@ -30,7 +30,9 @@ using namespace std;
 #ifdef ENABLE_LINUX_PPDEV
 #  include "LinuxPPDevIO.h"
 #endif
-#include "DirectPPIO.h"
+#ifdef ENABLE_DIRECTIO
+#  include "DirectPPIO.h"
+#endif
 #include "Util.h"
 
 
@@ -42,9 +44,12 @@ IO *IO::acquire(char *name, int port) {
 		io = new LinuxPPDevIO(port);
 	} else
 #endif
+#ifdef ENABLE_DIRECTIO
 	if(strcasecmp(name, "DirectPP") == 0) {
 		io = new DirectPPIO(port);
-	} else {
+	} else
+#endif
+	{
 		throw runtime_error("Unknown IO driver selected");
 	}
 	io->off();
