@@ -14,7 +14,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: LinuxPPDevIO.cxx,v 1.14 2004/11/20 20:50:49 marka Exp $
+ * $Id: LinuxPPDevIO.cxx,v 1.15 2006/04/29 14:55:08 marka Exp $
  */
 using namespace std;
 
@@ -62,6 +62,9 @@ LinuxPPDevIO::LinuxPPDevIO(int port) : ParallelPort(port)  {
 		close(this->fd);
 		throw runtime_error(strerror(err));
 	}
+    /* TODO generalize this hack */
+    set_pin_state("vpp1", 0, 3, true, false);
+    set_pin_state("vpp3", 0, 5, true, false);
 }
 
 
