@@ -14,7 +14,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: PicDevice.cxx,v 1.32 2004/11/20 15:08:39 marka Exp $
+ * $Id: PicDevice.cxx,v 1.33 2006/04/29 14:55:08 marka Exp $
  */
 using namespace std;
 
@@ -67,6 +67,8 @@ Device *PicDevice::load(char *name) {
 		return new Pic12f6xxDevice(name);
 	} else if(Util::regex_match("^PIC16.*", name)) {
 		return new Pic16Device(name);
+	} else if(Util::regex_match("^PIC18F((2..[05])|(2.21)|(4..[05])|(4.21))", name)) {
+		return new Pic18f2xx0Device(name);
 	} else if(Util::regex_match("^PIC18.*", name)) {
 		return new Pic18Device(name);
 	}
@@ -238,3 +240,9 @@ uint32_t PicDevice::read_prog_data(void) {
 	this->io->usleep(1);
 	return (data >> 1) & this->wordmask;
 }
+
+void PicDevice::set_config_default(DataBuffer& buf)
+{
+	/* On most PICs, the configuration memory is only = 0xffff but it is not always the case */
+	/* TODO should be done through the pic.conf configuration */
+}
