@@ -14,7 +14,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: PicDevice.h,v 1.42 2004/09/26 15:49:00 marka Exp $
+ * $Id: PicDevice.h,v 1.43 2006/04/29 14:55:08 marka Exp $
  */
 #ifndef __PicDevice_h
 #define __PicDevice_h
@@ -164,6 +164,10 @@ protected:
 	 */
 	virtual uint32_t read_deviceid(void);
 	
+	/** Prepare the default value of the configuration registers.
+	 */
+	virtual void set_config_default(DataBuffer& buf);
+	
 /* Protected data: */
 	/** The calculated bitmask for clearing upper bits of a word. */
 	uint32_t wordmask;
@@ -651,11 +655,46 @@ protected:
 	virtual unsigned int write_command_read_data(unsigned int command);
 
 	virtual uint32_t read_deviceid(void);
+	
+	virtual void set_config_default(DataBuffer& buf);
 
 /* Protected Data: */
 	/** The bitmasks for each configuration word */
 	unsigned int config_masks[7];
 };
 
+class Pic18f2xx0Device : public Pic18Device {
+public:
+	/* PIC18* commands */
+	const static int
+		COMMAND_TABLE_WRITE_START_POSTINC=0x0e;/**< Table Write, start programming, post-inc by 2 */
+
+	const static unsigned long
+		WRITE_BUFFER_SIZE=32; /* TODO generalize to a pic.conf parameter : 32 is for 18f4550 */
+	const static unsigned long
+		ERASE_BUFFER_SIZE=64; /* TODO idem */
+	
+	Pic18f2xx0Device(char *name);	/**< Constructor */
+	virtual ~Pic18f2xx0Device();		/**< Destructor */
+
+	virtual void erase(void);
+
+protected:
+	virtual void write_program_memory(DataBuffer& buf, bool verify);
+
+	virtual void write_id_memory(DataBuffer& buf, unsigned long addr, bool verify);
+
+	virtual void write_data_memory(DataBuffer& buf, unsigned long addr, bool verify);
+
+	virtual void write_config_memory(DataBuffer& buf, unsigned long addr, bool verify);
+
+	virtual void read_data_memory(DataBuffer& buf, unsigned long addr, bool verify);
+
+	void load_write_buffer(unsigned int word, bool last);
+	
+	virtual void program_wait(void);
+
+};
+
 
 #endif
