@@ -14,7 +14,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: main.cxx,v 1.34 2004/11/20 23:21:59 marka Exp $
+ * $Id: main.cxx,v 1.36 2006/04/29 14:55:08 marka Exp $
  */
 using namespace std;
 
@@ -58,10 +58,10 @@ static int do_test(int argc, char *argv[]);
 
 
 static const struct cmd {
-	char *name;
+	const char *name;
 	int  (*func)(int argc, char *argv[]);
 	bool requires_chiptype;
-	char *desc;
+	const char *desc;
 } commands[] = {
 	{"init", do_init, false, "Prepares the programmer board for use"},
 	{"test", do_test, false, "Enters programmer board test mode"},
@@ -132,7 +132,7 @@ int main(int argc, char *argv[]) {
 	char ioname[30];
 	int retval, i;
 	long ioport;
-	char *user_configfile="config";
+	const char *user_configfile="config";
 	vector<string> var_override;
 
 	quiet = false;
@@ -460,6 +460,8 @@ static int do_erase(int argc, char *argv[]) {
 static int do_blankcheck(int argc, char *argv[]) {
 	DataBuffer buf(device->get_wordsize());
 
+	device->set_config_default(buf);
+
 	printf("Verifying a device is blank.\n");
 	try {
 		/* Verify the contents of the device */
